@@ -35,6 +35,7 @@ from http.client import InvalidURL
 from itertools import count
 from json import dumps as json_dumps
 from os import fsencode, PathLike
+from platform import system
 from pickle import dumps as pickle_dumps, loads as pickle_loads
 from posixpath import join as joinpath, split as splitpath, splitext
 from stat import S_IFDIR, S_IFREG
@@ -44,6 +45,7 @@ from _thread import start_new_thread, allocate_lock
 from time import sleep, time
 from typing import cast, Any, Concatenate, Final, IO, ParamSpec
 from unicodedata import normalize
+from urllib.parse import quote
 
 from alist import AlistFileSystem, AlistPath
 from filewrap import Buffer
@@ -57,6 +59,7 @@ from .log import logger
 Args = ParamSpec("Args")
 
 urllib3_request = partial(request, pool=PoolManager(64))
+PLATFORM = system()
 
 
 def _get_process():
@@ -100,7 +103,7 @@ def readdir_future_wrapper(
                         if cooldown_pool is not None and future.exception() is None:
                             cooldown_pool[path] = None
                         pop_task(path, None)
-                    future = task_pool[path] = submit(readdir, self, path, fh)
+                    future = task_pool[path] = submit(readdir, self, path, fh) # type: ignore
                     future.add_done_callback(done_callback)
         if result is None:
             return future.result()
@@ -279,8 +282,15 @@ class AlistFuseOperations(Operations):
                 ):
                     process.kill()
                     def push():
-                        sleep(.01)
-                        run([exe, self.fs.get_url(path.lstrip("/"))])
+                        sign = self.getattr(path)["_attr"].get("sign")
+                        url = self.fs.get_url(path.lstrip("/"), ensure_ascii=False)
+                        if sign:
+                            url += "?sign=" + quote(sign)
+                        sleep(0.01)
+                        if PLATFORM == "Darwin":
+                            run(["open", "-a", exe, url])
+                        else:
+                            run([exe, url])
                     start_new_thread(push, ())
                     return 0
             except Exception as e:
